{% if follow_status == 0 %}
<div class="feed-item">
	<a class="btn btn-success" href="{% url pin-follow latest_items.0.user.id 1 %}">دنبال کردن</a>
</div>
{% else %}
<div class="feed-item">
	<a class="btn btn-danger" href="{% url pin-follow latest_items.0.user.id 0 %}">قطع ارتباط</a>
</div>
{%endif%}